/*
 * iFacturasItemBean.java
 *
 * Created on 20 de septiembre de 2003, 9:41
 * 
 * Este EJB representa los elementos persistentes en la Base de Datos
 *
 */

package ejbfacturas;

/**
 * @author Roberto Canales
 */

import java.rmi.*;
import javax.ejb.*;
import java.sql.*;
import javax.sql.*;
import java.util.*;

import facturascomun.*;


public class iFacturaItemBean implements EntityBean
{    
    private void depura(String cadena)
    {
        System.out.println("EJB iFacturaItemBean: " + cadena);
    }
    
    
    /**
    *    Declaracin de miembros
    */   
    private String iId;  // clave primaria de nuestra factura
    private String sTitular;
    private String sConcepto;
    private String sCif;
    private String sDireccion;
    private String sFecha;
    private double dCandidad;
    
    private EntityContext context = null;
    private Connection con = null;

    
    /** 
     * Metodo destinado a construir nuestro objeto 
     * 
     * Debe retornar la clave primaria del objeto creado
     */
    public String ejbCreate(Factura pFactura) throws CreateException 
    {
        if (pFactura == null)
        {
            throw new CreateException("El Objeto retornado es nulo");
        }
        
        // asignamos las propiedades a los miembros de nuestra clase
        iId         = pFactura.getId();  // clave primaria de nuestra factura
        sTitular    = pFactura.getTitular();
        sConcepto   = pFactura.getConcepto();
        sCif        = pFactura.getCif();
        sDireccion  = pFactura.getDireccion();
        sFecha      = pFactura.getFecha();
        dCandidad   = pFactura.getCandidad(); 
        
        insertaFila();
        
        return iId;
    }

    /**
     * PosCreate del create construido     
     */
    public void ejbPostCreate(Factura pFactura) throws CreateException 
    {
        depura("Enviado post-create");
        // no es necesario cdigo aunque si el metodo por haber escrito un create
    }
    
    /**
     * Metodo encargado de localizar un elemento por clave primaria
     *
     * Es un metodo obligatorio
     * Retorna la clave primaria de la entidad
     * Nunca se llama este metodo directamente.
     *
     */
    public String ejbFindByPrimaryKey(String pParam) throws FinderException
    {
        depura("Invocado buscar por id " + pParam);
        if (encuentroElemento(pParam) == false)
        {
              throw new ObjectNotFoundException();  
        }
        
        return pParam;
    }
    
    /**
     * Metodo que verifica la existencia de un elemento concreto
     */
    private boolean encuentroElemento(String sParam)
    {
        // Este cdigo lo usamos solamente para probar el concepto
        if(sParam.compareTo("22") == 0)
        {
            return true;  // solo nos interesa el valor cero
        }
        
        return false;
    }
    
    /**
     * Metodo que realiza la insercin
     * Lo separamos del create para desacoplar funcionalidades
     */
    void insertaFila() throws CreateException
    {
        depura("Insertamos Fila para id " + iId);
    }
    
    
    
    /** 
     * Metodo invocado por el contenedor para reactivar la instancia
     */
    public void ejbActivate() {
        iId = (String)context.getPrimaryKey(); // recuperamos la clave primaria
        depura("Se activa el EJB para id " + iId);
    }
    
    
    /** 
     * Metodo invocado por el contenedor para desactivar la instancia
     */
    public void ejbPassivate() {
        depura("Se pasiva el EJB para id " + iId);
    
        iId = null;  // eliminamos la referencia actual
    }
    
    /** 
     * Metodo invocado por el contenedor para borrar la instancia
     */
    public void ejbRemove()  throws RemoveException {
        borraFila();        
    }
    
    void borraFila() throws RemoveException
    {
        depura("Borramos el EJB para id " + iId);
    }
    
    /** 
     * Metodo invocado por el contenedor para cargar de BBDD los datos de la instancia
     */
    public void ejbLoad() throws javax.ejb.EJBException, java.rmi.RemoteException {
        
        cargaDatos();
    }
    
    void cargaDatos() throws NoSuchEntityException
    {
        depura("Mandan cargar datos para ID = " + iId);
              
        if(iId.compareTo("22") == 0)
        {
            sTitular        = "adictosaltrabajo"  ;
            sConcepto       = "consultoria";
            sCif            = "b64554432";
            sDireccion      = "Mi casa";
            sFecha          = "01102003";
            dCandidad       = 1000;
        }
    }
    
    
     /** 
     * Metodo invocado por el contenedor para almacenar los datos cambiados
     */
    public void ejbStore() throws javax.ejb.EJBException, java.rmi.RemoteException {
        guardaDatos();
    }

    void guardaDatos() throws NoSuchEntityException
    {
        depura("Guardamos el EJB para id = " + iId);
    }
    
    
    /**
     * Metodo para localizar las facturas adecuadas
     */
    public Collection ejbFindByRango(int pOrigen,int pDestino) throws FinderException
    {        
        depura("Retornamos entre el Rango: " + pOrigen + " y :" + pDestino);
        return null;
    }
    
    
    
     /** 
     * Metodo invocado por el contenedor para pasarnos y desactivar el contexto
     */
    public void setEntityContext(javax.ejb.EntityContext entityContext) throws javax.ejb.EJBException, java.rmi.RemoteException {
            depura("Establecemos el contexto");
            this.context = entityContext; // si se nos olvida fallara el ejbActivate
    }
    
    public void unsetEntityContext() throws javax.ejb.EJBException, java.rmi.RemoteException {
            depura("Des-establecemos el contexto");
            context = null;
    }
    
    /** Metodo get para  sConcepto.
     * @return Value of property sConcepto.
     *
     */
    public String getSConcepto() {
        return sConcepto;
    }
    
    /** Metodo set para sConcepto.
     * @param sConcepto Nuevo valor de propiedadsConcepto.
     *
     */
    public void setSConcepto(String sConcepto) {
        this.sConcepto = sConcepto;
    }
    
    /** Metodo get para  sFecha.
     * @return Value of property sFecha.
     *
     */
    public String getSFecha() {
        return sFecha;
    }
    
    /** Metodo set para sFecha.
     * @param sFecha Nuevo valor de propiedadsFecha.
     *
     */
    public void setSFecha(String sFecha) {
        this.sFecha = sFecha;
    }
    
    /** Metodo get para  sDireccion.
     * @return Value of property sDireccion.
     *
     */
    public String getSDireccion() {
        return sDireccion;
    }
    
    /** Metodo set para sDireccion.
     * @param sDireccion Nuevo valor de propiedadsDireccion.
     *
     */
    public void setSDireccion(String sDireccion) {
        this.sDireccion = sDireccion;
    }
    
    /** Metodo get para  sTitular.
     * @return Value of property sTitular.
     *
     */
    public String getSTitular() {
        return sTitular;
    }
    
    /** Metodo set para sTitular.
     * @param sTitular Nuevo valor de propiedadsTitular.
     *
     */
    public void setSTitular(String sTitular) {
        this.sTitular = sTitular;
    }
    
    /** Metodo get para  sCif.
     * @return Value of property sCif.
     *
     */
    public String getSCif() {
        return sCif;
    }
    
    /** Metodo set para sCif.
     * @param sCif Nuevo valor de propiedadsCif.
     *
     */
    public void setSCif(String sCif) {
        this.sCif = sCif;
    }
    
    /** Metodo get para  iId.
     * @return Value of property iId.
     *
     */
    public String getIId() {
        return iId;
    }
    
    /** Metodo set para iId.
     * @param iId Nuevo valor de propiedadiId.
     *
     */
    public void setIId(String iId) {
        this.iId = iId;
    }
    
    /** Metodo get para  dCandidad.
     * @return Value of property dCandidad.
     *
     */
    public double getDCandidad() {
        return dCandidad;
    }
    
    /** Metodo set para dCandidad.
     * @param dCandidad Nuevo valor de propiedaddCandidad.
     *
     */
    public void setDCandidad(double dCandidad) {
        this.dCandidad = dCandidad;
    }
}