/*
 * iFacturasItemBean.java
 *
 * Created on 20 de septiembre de 2003, 9:41
 * 
 * Este EJB representa los elementos persistentes en la Base de Datos
 *
 */
package ejbfacturas;

/**
 * @author Roberto Canales
 */

import java.rmi.*;
import javax.ejb.*;
import java.sql.*;
import javax.sql.*;
import java.util.*;

import facturascomun.*;


public abstract class iFacturaItemBeanCMP implements EntityBean
{    
    private void depura(String cadena)
    {
        System.out.println("EJB iFacturaItemBeanCMP: " + cadena);
    }
    
    
    private EntityContext context = null;
    
    /** 
     * Metodo destinado a construir nuestro objeto 
     * 
     * Debe retornar la clave primaria del objeto creado
     */
    public String ejbCreate(Factura pFactura) throws CreateException 
    {
        if (pFactura == null)
        {
            throw new CreateException("El Objeto retornado es nulo");
        }
              
        // asignamos las propiedades a los miembros de nuestra clase
        this.setId(pFactura.getId());  // clave primaria de nuestra factura
        this.setTitular(pFactura.getTitular());
        this.setConcepto(pFactura.getConcepto());
        this.setCif(pFactura.getCif());
        this.setDireccion(pFactura.getDireccion());
        this.setFecha(pFactura.getFecha());
        this.setCantidad(pFactura.getCandidad()); 
        
        return null;  // en un CMP se retorna NULL
    }

    /**
     * PosCreate del create construido     
     */
    public void ejbPostCreate(Factura pFactura) throws CreateException 
    {
        depura("Enviado post-create");
        // no es necesario cdigo aunque si el metodo por haber escrito un create
    }
    
    
    /** 
     * Metodo invocado por el contenedor para reactivar la instancia
     */
    public void ejbActivate() {
         depura("Se activa el EJB");
    }
    
    
    /** 
     * Metodo invocado por el contenedor para desactivar la instancia
     */
    public void ejbPassivate() {
        depura("Se pasiva el EJB");
    }
    
    /** 
     * Metodo invocado por el contenedor para borrar la instancia
     */
    public void ejbRemove()  throws RemoveException {
        depura("Borramos el EJB para id ");
     }
    
    /** 
     * Metodo invocado por el contenedor para cargar de BBDD los datos de la instancia
     */
    public void ejbLoad() throws javax.ejb.EJBException, java.rmi.RemoteException {
        
        depura("Cargamos datos el EJB ");
    }
     
     /** 
     * Metodo invocado por el contenedor para almacenar los datos cambiados
     */
    public void ejbStore() throws javax.ejb.EJBException, java.rmi.RemoteException {
        depura("Guardamos datos el EJB");
    }


     /** 
     * Metodo invocado por el contenedor para pasarnos y desactivar el contexto
     */
    public void setEntityContext(javax.ejb.EntityContext entityContext) throws javax.ejb.EJBException, java.rmi.RemoteException {
            depura("Establecemos el contexto");
            this.context = entityContext; // si se nos olvida fallara el ejbActivate
    }
    
    
    public void unsetEntityContext() throws javax.ejb.EJBException, java.rmi.RemoteException {
            depura("Des-establecemos el contexto");
            context = null;
    }

    
    public abstract String getConcepto();
    public abstract void setConcepto(String sConcepto);
    public abstract String getFecha();
    public abstract void setFecha(String sFecha);
    public abstract String getDireccion();
    public abstract void setDireccion(String sDireccion); 
    public abstract String getTitular();
    public abstract void setTitular(String sTitular);
    public abstract String getCif() ;
    public abstract void setCif(String sCif);
    public abstract String getId();
    public abstract void setId(String iId);
    public abstract double getCantidad();
    public abstract void setCantidad(double dCantidad);

}